@@ -31,6 +31,7 @@ __all__ = [
     'BaseClient',
     'API_PUBLIC_ENDPOINT',
     'API_PRIVATE_ENDPOINT',
+    'IAMClient',
 ]
 
 VALID_CALL_ARGS = set((
@@ -176,7 +177,7 @@ class BaseClient(object):
                     endpoint_url=url,
                     proxy=self.settings['softlayer'].get('proxy'),
                     # prevents an exception incase timeout is a float number.
-                    timeout=int(self.settings['softlayer'].getfloat('timeout')),
+                    timeout=int(self.settings['softlayer'].getfloat('timeout', 0)),
                     user_agent=consts.USER_AGENT,
                     verify=self.settings['softlayer'].getboolean('verify'),
                 )
@@ -185,7 +186,7 @@ class BaseClient(object):
                 transport = transports.XmlRpcTransport(
                     endpoint_url=url,
                     proxy=self.settings['softlayer'].get('proxy'),
-                    timeout=int(self.settings['softlayer'].getfloat('timeout')),
+                    timeout=int(self.settings['softlayer'].getfloat('timeout', 0)),
                     user_agent=consts.USER_AGENT,
                     verify=self.settings['softlayer'].getboolean('verify'),
                 )
