@@ -24,6 +24,7 @@ ALL_ROUTES = [
     ('account:cancel-item', 'SoftLayer.CLI.account.cancel_item:cli'),
     ('account:orders', 'SoftLayer.CLI.account.orders:cli'),
     ('account:bandwidth-pools', 'SoftLayer.CLI.account.bandwidth_pools:cli'),
+    ('account:hooks', 'SoftLayer.CLI.account.hooks:cli'),
 
     ('virtual', 'SoftLayer.CLI.virt'),
     ('virtual:bandwidth', 'SoftLayer.CLI.virt.bandwidth:cli'),
@@ -52,7 +53,14 @@ ALL_ROUTES = [
     ('virtual:capacity', 'SoftLayer.CLI.virt.capacity:cli'),
     ('virtual:placementgroup', 'SoftLayer.CLI.virt.placementgroup:cli'),
     ('virtual:migrate', 'SoftLayer.CLI.virt.migrate:cli'),
+    ('virtual:access', 'SoftLayer.CLI.virt.access:cli'),
     ('virtual:monitoring', 'SoftLayer.CLI.virt.monitoring:cli'),
+    ('virtual:notifications', 'SoftLayer.CLI.virt.notifications:cli'),
+    ('virtual:notification-add', 'SoftLayer.CLI.virt.notification_add:cli'),
+    ('virtual:notification-delete', 'SoftLayer.CLI.virt.notification_delete:cli'),
+    ('virtual:host-list', 'SoftLayer.CLI.dedicatedhost.list:cli'),
+    ('virtual:host-create', 'SoftLayer.CLI.dedicatedhost.create:cli'),
+    ('virtual:os-available', 'SoftLayer.CLI.virt.os_available:cli'),
 
     ('dedicatedhost', 'SoftLayer.CLI.dedicatedhost'),
     ('dedicatedhost:list', 'SoftLayer.CLI.dedicatedhost.list:cli'),
@@ -201,6 +209,8 @@ ALL_ROUTES = [
     ('image:import', 'SoftLayer.CLI.image.import:cli'),
     ('image:export', 'SoftLayer.CLI.image.export:cli'),
     ('image:datacenter', 'SoftLayer.CLI.image.datacenter:cli'),
+    ('image:share', 'SoftLayer.CLI.image.share:cli'),
+    ('image:share-deny', 'SoftLayer.CLI.image.share_deny:cli'),
 
     ('ipsec', 'SoftLayer.CLI.vpn.ipsec'),
     ('ipsec:configure', 'SoftLayer.CLI.vpn.ipsec.configure:cli'),
@@ -213,6 +223,7 @@ ALL_ROUTES = [
     ('ipsec:translation-update', 'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
     ('ipsec:update', 'SoftLayer.CLI.vpn.ipsec.update:cli'),
     ('ipsec:order', 'SoftLayer.CLI.vpn.ipsec.order:cli'),
+    ('ipsec:cancel', 'SoftLayer.CLI.vpn.ipsec.cancel:cli'),
 
     ('loadbal', 'SoftLayer.CLI.loadbal'),
     ('loadbal:detail', 'SoftLayer.CLI.loadbal.detail:cli'),
@@ -272,7 +283,6 @@ ALL_ROUTES = [
     ('hardware:detail', 'SoftLayer.CLI.hardware.detail:cli'),
     ('hardware:billing', 'SoftLayer.CLI.hardware.billing:cli'),
     ('hardware:edit', 'SoftLayer.CLI.hardware.edit:cli'),
-    ('hardware:guests', 'SoftLayer.CLI.hardware.guests:cli'),
     ('hardware:list', 'SoftLayer.CLI.hardware.list:cli'),
     ('hardware:power-cycle', 'SoftLayer.CLI.hardware.power:power_cycle'),
     ('hardware:power-off', 'SoftLayer.CLI.hardware.power:power_off'),
@@ -291,6 +301,10 @@ ALL_ROUTES = [
     ('hardware:upgrade', 'SoftLayer.CLI.hardware.upgrade:cli'),
     ('hardware:sensor', 'SoftLayer.CLI.hardware.sensor:cli'),
     ('hardware:monitoring', 'SoftLayer.CLI.hardware.monitoring:cli'),
+    ('hardware:notifications', 'SoftLayer.CLI.hardware.notifications:cli'),
+    ('hardware:notification-add', 'SoftLayer.CLI.hardware.notification_add:cli'),
+    ('hardware:notification-delete', 'SoftLayer.CLI.hardware.notification_delete:cli'),
+    ('hardware:create-credential', 'SoftLayer.CLI.hardware.create_credential:cli'),
 
     ('securitygroup', 'SoftLayer.CLI.securitygroup'),
     ('securitygroup:list', 'SoftLayer.CLI.securitygroup.list:cli'),
@@ -333,6 +347,7 @@ ALL_ROUTES = [
     ('subnet:lookup', 'SoftLayer.CLI.subnet.lookup:cli'),
     ('subnet:edit-ip', 'SoftLayer.CLI.subnet.edit_ip:cli'),
     ('subnet:route', 'SoftLayer.CLI.subnet.route:cli'),
+    ('subnet:clear-route', 'SoftLayer.CLI.subnet.clear_route:cli'),
 
     ('tags', 'SoftLayer.CLI.tags'),
     ('tags:cleanup', 'SoftLayer.CLI.tags.cleanup:cli'),
@@ -367,6 +382,7 @@ ALL_ROUTES = [
     ('user:vpn-manual', 'SoftLayer.CLI.user.vpn_manual:cli'),
     ('user:vpn-subnet', 'SoftLayer.CLI.user.vpn_subnet:cli'),
     ('user:remove-access', 'SoftLayer.CLI.user.remove_access:cli'),
+    ('user:grant-access', 'SoftLayer.CLI.user.grant_access:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
@@ -377,20 +393,11 @@ ALL_ROUTES = [
     ('vlan:cancel', 'SoftLayer.CLI.vlan.cancel:cli'),
 
     ('summary', 'SoftLayer.CLI.summary:cli'),
+    ('search', 'SoftLayer.CLI.search:cli'),
 
     ('report', 'SoftLayer.CLI.report'),
     ('report:bandwidth', 'SoftLayer.CLI.report.bandwidth:cli'),
     ('report:datacenter-closures', 'SoftLayer.CLI.report.dc_closures:cli'),
-
-    ('autoscale', 'SoftLayer.CLI.autoscale'),
-    ('autoscale:list', 'SoftLayer.CLI.autoscale.list:cli'),
-    ('autoscale:create', 'SoftLayer.CLI.autoscale.create:cli'),
-    ('autoscale:detail', 'SoftLayer.CLI.autoscale.detail:cli'),
-    ('autoscale:scale', 'SoftLayer.CLI.autoscale.scale:cli'),
-    ('autoscale:logs', 'SoftLayer.CLI.autoscale.logs:cli'),
-    ('autoscale:tag', 'SoftLayer.CLI.autoscale.tag:cli'),
-    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli'),
-    ('autoscale:delete', 'SoftLayer.CLI.autoscale.delete:cli'),
 ]
 
 ALL_ALIASES = {
