@@ -14,7 +14,7 @@ getPrivateBlockDeviceTemplateGroups = [{
     'globalIdentifier': 'F9329795-4220-4B0A-B970-C86B950667FA',
     'id': 201,
     # 'name': 'private_image2',
-    'name': u'a¬ሴ€耀',
+    'name': 'a¬ሴ€耀',
     'parentId': '',
     'publicFlag': False,
 }]
@@ -485,7 +485,7 @@ getCdnAccounts = [
 
 getNetworkVlans = [{
     'id': 1,
-    'networkSpace': 'PRIVATE',
+    'networkSpace': '',
     'hardwareCount': 0,
     'hardware': [],
     'vlanNumber': 12,
@@ -501,6 +501,7 @@ getNetworkVlans = [{
     'totalPrimaryIpAddressCount': 1,
     'subnetCount': 0,
     'subnets': [],
+    'tagReferences': [],
     'firewallInterfaces': [
         {
             'id': 1,
@@ -538,6 +539,7 @@ getNetworkVlans = [{
     'firewallInterfaces': [],
 
     'subnetCount': 0,
+    'tagReferences': [],
     'subnets': [],
 }, {
     'id': 3,
@@ -561,6 +563,7 @@ getNetworkVlans = [{
     'totalPrimaryIpAddressCount': 3,
     'subnetCount': 0,
     'subnets': [],
+    'tagReferences': [],
     'virtualGuestCount': 1,
     'virtualGuests': [{'id': 3}]
 }]
@@ -644,8 +647,36 @@ getBalance = 40
 
 getNextInvoiceTotalAmount = 2
 
-getHubNetworkStorage = [{'id': 12345, 'username': 'SLOS12345-1', 'serviceResource': {'name': 'Cleversafe - US Region'}},
-                        {'id': 12346, 'username': 'SLOS12345-2', 'vendorName': 'Swift'}]
+getHubNetworkStorage = [
+    {
+        "id": 12345,
+        "username": "SLOS12345-1",
+        "billingItem": {
+            "createDate": "2020-10-08T11:45:17-06:00"
+        },
+        "serviceResource": {
+            "name": "Cleversafe - US Region"
+        },
+        "storageType": {
+            "description": "Object Storage Standard Account",
+            "id": 24,
+            "keyName": "OBJECT_STORAGE_STANDARD"
+        }
+    },
+    {
+        "id": 12346,
+        "username": "SLOS12345-2",
+        "vendorName": "Swift",
+        "billingItem": {
+            "createDate": "2020-10-08T11:45:17-06:00"
+        },
+        "storageType": {
+            "description": "Object Storage Standard Account",
+            "id": 24,
+            "keyName": "OBJECT_STORAGE_STANDARD"
+        }
+    }
+]
 
 getIscsiNetworkStorage = [{
     'accountId': 1234,
@@ -673,17 +704,192 @@ getVirtualDedicatedRacks = [{
     'metricTrackingObjectId': 10,
 }]
 
-getDedicatedHosts = [{
-    'datacenter': {
-        'name': 'dal05'
-    },
-    'memoryCapacity': 242,
-    'name': 'test-dedicated',
-    'diskCapacity': 1200,
-    'guestCount': 1,
-    'cpuCount': 56,
-    'id': 12345
-}]
+getDedicatedHosts = [
+    {
+        "cpuCount": 56,
+        "createDate": "2021-11-18T15:13:57-06:00",
+        "diskCapacity": 1200,
+        "id": 656700,
+        "memoryCapacity": 242,
+        "name": "dedicatedhost01",
+        "guestCount": 0,
+        "allocationStatus": {
+            "cpuAllocated": 0,
+            "cpuAvailable": 56,
+            "cpuCount": 56,
+            "diskAllocated": 0,
+            "diskAvailable": 1200,
+            "diskCapacity": 1200,
+            "guestCount": 0,
+            "memoryAllocated": 0,
+            "memoryAvailable": 242,
+            "memoryCapacity": 242
+        },
+        "backendRouter": {
+            "accountId": 1,
+            "bareMetalInstanceFlag": 0,
+            "domain": "softlayer.com",
+            "fullyQualifiedDomainName": "bcr01a.dal13.softlayer.com",
+            "hardwareStatusId": 5,
+            "hostname": "bcr01a.dal13",
+            "id": 1883692,
+            "notes": "",
+            "provisionDate": None,
+            "serviceProviderId": 1,
+            "serviceProviderResourceId": None
+        },
+        "billingItem": {
+            "allowCancellationFlag": 1,
+            "cancellationDate": None,
+            "categoryCode": "dedicated_virtual_hosts",
+            "createDate": "2021-11-18T15:13:59-06:00",
+            "currentHourlyCharge": "0",
+            "cycleStartDate": "2023-01-04T00:07:36-06:00",
+            "description": "56 Cores X 242 RAM X 1.2 TB",
+            "hostName": "dedicatedhost01",
+            "hourlyRecurringFee": "0",
+            "hoursUsed": "465",
+            "id": 910104016,
+            "laborFee": "0",
+            "laborFeeTaxRate": "0",
+            "lastBillDate": "2023-01-04T00:07:36-06:00",
+            "modifyDate": "2023-01-04T00:07:36-06:00",
+            "nextBillDate": "2023-02-04T00:00:00-06:00",
+            "oneTimeFee": "0",
+            "oneTimeFeeTaxRate": "0",
+            "orderItemId": 874370304,
+            "parentId": None,
+            "recurringFee": "0",
+            "recurringFeeTaxRate": "0",
+            "recurringMonths": 1,
+            "serviceProviderId": 1,
+            "setupFee": "0",
+            "setupFeeTaxRate": "0",
+            "orderItem": {
+                "categoryCode": "dedicated_virtual_hosts",
+                "description": "56 Cores X 242 RAM X 1.2 TB",
+                "hostName": "dedicatedhost01",
+                "hourlyRecurringFee": "0",
+                "id": 874370304,
+                "itemId": 10195,
+                "itemPriceId": "200269",
+                "laborAfterTaxAmount": "0",
+                "laborFee": "0",
+                "laborFeeTaxRate": "0",
+                "laborTaxAmount": "0",
+                "oneTimeAfterTaxAmount": "0",
+                "oneTimeFee": "0",
+                "oneTimeFeeTaxRate": "0",
+                "oneTimeTaxAmount": "0",
+                "parentId": None,
+                "presetId": None,
+                "promoCodeId": None,
+                "quantity": None,
+                "recurringAfterTaxAmount": "0",
+                "recurringFee": "0",
+                "recurringTaxAmount": "0",
+                "setupAfterTaxAmount": "0",
+                "setupFee": "0",
+                "setupFeeDeferralMonths": None,
+                "setupFeeTaxRate": "0",
+                "setupTaxAmount": "0",
+                "order": {
+                    "accountId": 307608,
+                    "createDate": "2021-11-18T15:13:57-06:00",
+                    "id": 85857762,
+                    "impersonatingUserRecordId": None,
+                    "modifyDate": "2021-11-18T15:14:00-06:00",
+                    "orderQuoteId": None,
+                    "orderTypeId": 11,
+                    "presaleEventId": None,
+                    "privateCloudOrderFlag": False,
+                    "status": "APPROVED",
+                    "userRecordId": 7650493,
+                    "userRecord": {
+                        "accountId": 307608,
+                        "address1": "4849 Alpha Rd",
+                        "city": "Dallas",
+                        "companyName": "SoftLayer Internal - Development Community",
+                        "country": "US",
+                        "createDate": "2019-06-10T15:21:33-07:00",
+                        "daylightSavingsTimeFlag": False,
+                        "denyAllResourceAccessOnCreateFlag": False,
+                        "displayName": "danielc",
+                        "email": "daniel.cabero@jalasoft.com",
+                        "firstName": "daniel",
+                        "forumPasswordHash": "unused",
+                        "iamAuthorizationStatus": 1,
+                        "iamId": "IBMid-550003CUGT",
+                        "id": 7650493,
+                        "isMasterUserFlag": False,
+                        "lastName": "cabero",
+                        "localeId": 1,
+                        "managedByFederationFlag": False,
+                        "managedByOpenIdConnectFlag": True,
+                        "minimumPasswordLifeHours": 0,
+                        "modifyDate": "2019-12-13T07:29:07-06:00",
+                        "openIdConnectUserName": "daniel.cabero@jalasoft.com",
+                        "parentId": 167758,
+                        "passwordExpireDate": None,
+                        "permissionCheckLikeMasterUserFlag": 0,
+                        "postalCode": "75244-4608",
+                        "pptpVpnAllowedFlag": False,
+                        "preventPreviousPasswords": 0,
+                        "savedId": "7650493",
+                        "secondaryLoginManagementFlag": True,
+                        "secondaryLoginRequiredFlag": None,
+                        "secondaryPasswordModifyDate": "2019-06-10T15:21:33-07:00",
+                        "secondaryPasswordTimeoutDays": 0,
+                        "sslVpnAllowedFlag": False,
+                        "state": "TX",
+                        "statusDate": None,
+                        "timezoneId": 113,
+                        "userStatusId": 1001,
+                        "username": "sl307608-dcabero",
+                        "vpnManualConfig": False,
+                        "ibmIdLink": {
+                            "createDate": "2019-06-10T15:21:34-07:00",
+                            "defaultFlag": 1,
+                            "destinationUserAlphanumericId": "daniel%2ecabero@jalasoft%2ecom",
+                            "destinationUserId": None,
+                            "iamIdVerificationFlag": 2,
+                            "id": 1051135,
+                            "realm": "IBMid",
+                            "serviceProviderId": 348,
+                            "uniqueIdentifier": "IBMid-550003CUGT",
+                            "userId": 7650493
+                        },
+                        "locale": {
+                            "friendlyName": "English",
+                            "id": 1,
+                            "languageTag": "en-US",
+                            "name": "English"
+                        },
+                        "timezone": {
+                            "id": 113,
+                            "longName": "(GMT-06:00) America/Chicago - CST",
+                            "name": "America/Chicago",
+                            "offset": "-0600",
+                            "shortName": "CST"
+                        },
+                        "userStatus": {
+                            "id": 1001,
+                            "keyName": "ACTIVE",
+                            "name": "Active"
+                        }
+                    }
+                }
+            },
+            "resourceTableId": 656700
+        },
+        "datacenter": {
+            "id": 1854895,
+            "longName": "Dallas 13",
+            "name": "dal13",
+            "statusId": 2
+        }
+    }
+]
 
 getUsers = [
     {'displayName': 'ChristopherG',
@@ -814,7 +1020,7 @@ getApplicationDeliveryControllers = [
         'createDate': '2015-05-05T16:23:52-06:00',
         'id': 11449,
         'modifyDate': '2015-05-05T16:24:09-06:00',
-        'name': 'SLADC307608-1',
+        'name': 'TEST307608-1',
         'typeId': 2,
         'description': 'Citrix NetScaler VPX 10.5 10Mbps Standard',
         'managementIpAddress': '10.11.11.112',
@@ -1076,3 +1282,201 @@ getNetworkStorage = [
         "username": "SL01SEV1234567_111"
     }
 ]
+
+getNetworkMessageDeliveryAccounts = [
+    {
+        "accountId": 147258,
+        "createDate": "2020-07-06T10:29:11-06:00",
+        "id": 1232123,
+        "typeId": 21,
+        "username": "test_CLI@ie.ibm.com",
+        "vendorId": 1,
+        "type": {
+            "description": "Delivery of messages through e-mail",
+            "id": 21,
+            "keyName": "EMAIL",
+            "name": "Email"
+        },
+        "vendor": {
+            "id": 1,
+            "keyName": "SENDGRID",
+            "name": "SendGrid"
+        },
+        "emailAddress": "test_CLI@ie.ibm.com",
+        "smtpAccess": "1"
+    }
+]
+
+getActiveAccountLicenses = [{
+    "accountId": 123456,
+    "capacity": "4",
+    "key": "Y8GNS-7QRNG-OUIJO-MATEI-5GJRM",
+    "units": "CPU",
+    "billingItem": {
+        "allowCancellationFlag": 1,
+        "categoryCode": "software_license",
+        "cycleStartDate": "2021-06-03T23:11:22-06:00",
+        "description": "vCenter Server Appliance 6.0",
+        "id": 741258963,
+        "laborFee": "0",
+        "laborFeeTaxRate": "0",
+        "oneTimeFee": "0",
+        "oneTimeFeeTaxRate": "0",
+        "orderItemId": 963258741,
+        "recurringFee": "0",
+        "recurringFeeTaxRate": "0",
+        "recurringMonths": 1,
+        "serviceProviderId": 1,
+        "setupFee": "0",
+        "setupFeeTaxRate": "0"
+    },
+    "softwareDescription": {
+        "controlPanel": 0,
+        "id": 15963,
+        "licenseTermValue": 0,
+        "longDescription": "VMware vCenter 6.0",
+        "manufacturer": "VMware",
+        "name": "vCenter",
+        "operatingSystem": 0,
+        "version": "6.0",
+        "virtualLicense": 0,
+        "virtualizationPlatform": 0,
+        "requiredUser": "administrator@vsphere.local"
+    }
+},
+    {
+        "accountId": 123456,
+        "capacity": "4",
+        "key": "TSZES-SJF85-04GLD-AXA64-8O1EO",
+        "units": "CPU",
+        "billingItem": {
+            "allowCancellationFlag": 1,
+            "categoryCode": "software_license",
+            "description": "vCenter Server Appliance 6.x",
+            "id": 36987456,
+            "laborFee": "0",
+            "laborFeeTaxRate": "0",
+            "oneTimeFee": "0",
+            "oneTimeFeeTaxRate": "0",
+            "orderItemId": 25839,
+            "recurringFee": "0",
+            "recurringFeeTaxRate": "0",
+            "recurringMonths": 1,
+            "serviceProviderId": 1,
+            "setupFee": "0",
+            "setupFeeTaxRate": "0"
+        },
+        "softwareDescription": {
+            "controlPanel": 0,
+            "id": 1472,
+            "licenseTermValue": 0,
+            "longDescription": "VMware vCenter 6.0",
+            "manufacturer": "VMware",
+            "name": "vCenter",
+            "operatingSystem": 0,
+            "version": "6.0",
+            "virtualLicense": 0,
+            "virtualizationPlatform": 0,
+            "requiredUser": "administrator@vsphere.local"
+        }
+    }
+]
+
+getActiveVirtualLicenses = [{
+    "id": 12345,
+    "ipAddress": "192.168.23.78",
+    "key": "TEST.60220734.0000",
+    "billingItem": {
+        "categoryCode": "control_panel",
+        "description": "Plesk Onyx (Linux) - (Unlimited) - VPS "
+    },
+    "softwareDescription": {
+        "longDescription": "Plesk - Unlimited Domain w/ Power Pack for VPS 17.8.11 Linux",
+        "manufacturer": "Plesk",
+        "name": "Plesk - Unlimited Domain w/ Power Pack for VPS"
+    },
+    "subnet": {
+        "broadcastAddress": "192.168.23.79",
+        "cidr": 28,
+        "gateway": "192.168.23.65",
+        "id": 1973163,
+        "isCustomerOwned": False,
+        "isCustomerRoutable": False,
+        "netmask": "255.255.255.240",
+        "networkIdentifier": "128.116.23.64",
+        "networkVlanId": 123456,
+        "note": "test note",
+        "sortOrder": "1",
+        "subnetType": "ADDITIONAL_PRIMARY",
+        "totalIpAddresses": "16",
+        "usableIpAddressCount": "13",
+        "version": 4
+    }
+}]
+
+getBandwidthAllotments = [{
+    'billingCyclePublicBandwidthUsage': {
+        'amountIn': '6.94517',
+        'amountOut': '6.8859'
+    },
+    'id': 309961,
+    'locationGroup': {
+        'description': 'All Datacenters in Mexico',
+        'id': 262,
+        'locationGroupTypeId': 1,
+        'name': 'MEX',
+        'securityLevelId': None
+    },
+    'name': 'MexRegion',
+    'projectedPublicBandwidthUsage': 9.88,
+    'totalBandwidthAllocated': 3361
+}]
+
+getNetworkGateways = [{
+    'id': 615448,
+    'name': 'testFirewall-cgallo',
+    'networkSpace': 'BOTH',
+    'insideVlans': [],
+    'members': [
+        {
+            'id': 687820,
+            'hardware': {
+                'hostname': 'dft03.pod03.dal13'
+            }
+        }
+    ],
+    'networkFirewall': {
+        'id': 17438,
+        'datacenter': {
+            'name': 'dal13'
+        },
+        'firewallType': 'fortigate-security-appliance-10gb',
+        'rules': []
+    },
+    'privateIpAddress': {
+        'ipAddress': '10.37.115.70'
+    },
+    'publicIpAddress': {
+        'ipAddress': '67.228.206.245'
+    },
+    'publicVlan': {
+        'id': 3228726,
+        'primaryRouter': {
+            'hostname': 'fcr03a.dal13'
+        }
+    },
+    'status': {
+        'keyName': 'ACTIVE'
+    }
+}]
+
+getPostProvisioningHooks = [{
+    "id": 147258369,
+    "name": "testProv",
+    "uri": "http://test.com"
+},
+    {
+        "id": 123654,
+        "name": "GettestProv12345",
+        "uri": "http://test.com"
+    }]
