@@ -67,7 +67,7 @@ class BlockTests(testing.TestCase):
             'LUN Id': '2',
             'Notes': "{'status': 'available'}",
             'Endurance Tier': 'READHEAVY_TIER',
-            'IOPs': 1000,
+            'IOPs': 1000.0,
             'Snapshot Capacity (GB)': '10',
             'Snapshot Used (Bytes)': 1024,
             'Capacity (GB)': '20GB',
@@ -80,17 +80,12 @@ class BlockTests(testing.TestCase):
             'Replicant Count': '1',
             'Replication Status': 'Replicant Volume Provisioning '
                                   'has completed.',
-            'Replicant Volumes': [[
-                {'Replicant ID': 'Volume Name', '1784': 'TEST_REP_1'},
-                {'Replicant ID': 'Target IP', '1784': '10.3.174.79'},
-                {'Replicant ID': 'Data Center', '1784': 'wdc01'},
-                {'Replicant ID': 'Schedule', '1784': 'REPLICATION_HOURLY'},
-            ], [
-                {'Replicant ID': 'Volume Name', '1785': 'TEST_REP_2'},
-                {'Replicant ID': 'Target IP', '1785': '10.3.177.84'},
-                {'Replicant ID': 'Data Center', '1785': 'dal01'},
-                {'Replicant ID': 'Schedule', '1785': 'REPLICATION_DAILY'},
-            ]],
+            'Replicant Volumes': [
+                {'Name': 'Replicant Id', 'Value': 1785},
+                {'Name': 'Volume Name', 'Value': 'TEST_REP_2'},
+                {'Name': 'Target IP', 'Value': '10.3.177.84'},
+                {'Name': 'Data Center', 'Value': 'dal01'},
+                {'Name': 'Schedule', 'Value': 'REPLICATION_DAILY'}],
             'Original Volume Properties': [
                 {'Property': 'Original Volume Size',
                  'Value': '20'},
@@ -451,7 +446,7 @@ class BlockTests(testing.TestCase):
         order_mock.return_value = {}
 
         result = self.run_command(['block', 'snapshot-order', '1234',
-                                   '--capacity=10', '--tier=0.25'])
+                                   '--size=10', '--tier=0.25', '--iops=100'])
 
         self.assert_no_fail(result)
         self.assertEqual(result.output,
@@ -463,7 +458,7 @@ class BlockTests(testing.TestCase):
         order_mock.side_effect = ValueError('failure!')
 
         result = self.run_command(['block', 'snapshot-order', '1234',
-                                   '--capacity=10', '--tier=0.25'])
+                                   '--size=10', '--tier=0.25', '--iops=100'])
 
         self.assertEqual(2, result.exit_code)
         self.assertEqual('Argument Error: failure!', result.exception.message)
@@ -480,7 +475,7 @@ class BlockTests(testing.TestCase):
         }
 
         result = self.run_command(['block', 'snapshot-order', '1234',
-                                   '--capacity=10', '--tier=0.25'])
+                                   '--size=10', '--tier=0.25', '--iops=100'])
 
         self.assert_no_fail(result)
         self.assertEqual(result.output,
@@ -630,7 +625,8 @@ class BlockTests(testing.TestCase):
 
         result = self.run_command(['block', 'replica-order', '100',
                                    '--snapshot-schedule=DAILY',
-                                   '--location=dal05'])
+                                   '--datacenter=dal05',
+                                   '--iops=100'])
 
         self.assert_no_fail(result)
         self.assertEqual(result.output,
@@ -655,7 +651,8 @@ class BlockTests(testing.TestCase):
 
         result = self.run_command(['block', 'replica-order', '100',
                                    '--snapshot-schedule=DAILY',
-                                   '--location=dal05', '--tier=2'])
+                                   '--datacenter=dal05', '--tier=2',
+                                   '--iops=100'])
 
         self.assert_no_fail(result)
         self.assertEqual(result.output,
@@ -782,6 +779,24 @@ class BlockTests(testing.TestCase):
         result = self.run_command(['block', 'volume-limits'])
         self.assert_no_fail(result)
 
+    def test_volume_limit_empty_datacenter(self):
+        expect_result = {
+            'dal13': 52,
+            'global': 700,
+            'null': 50
+        }
+        result = self.run_command(['block', 'volume-limits'])
+        self.assert_no_fail(result)
+        self.assertEqual(json.loads(result.output), expect_result)
+
+    def test_volume_limit_datacenter(self):
+        expect_result = {
+            "dal13": 52
+        }
+        result = self.run_command(['block', 'volume-limits', '-d', 'dal13'])
+        self.assert_no_fail(result)
+        self.assertEqual(json.loads(result.output), expect_result)
+
     def test_dupe_refresh(self):
         result = self.run_command(['block', 'volume-refresh', '102', '103'])
 
