@@ -761,6 +761,24 @@ class FileTests(testing.TestCase):
         result = self.run_command(['file', 'volume-limits'])
         self.assert_no_fail(result)
 
+    def test_volume_limit_empty_datacenter(self):
+        expect_result = {
+            'dal13': 52,
+            'global': 700,
+            'null': 50
+        }
+        result = self.run_command(['file', 'volume-limits'])
+        self.assert_no_fail(result)
+        self.assertEqual(json.loads(result.output), expect_result)
+
+    def test_volume_limit_datacenter(self):
+        expect_result = {
+            "dal13": 52
+        }
+        result = self.run_command(['file', 'volume-limits', '-d', 'dal13'])
+        self.assert_no_fail(result)
+        self.assertEqual(json.loads(result.output), expect_result)
+
     def test_dupe_refresh(self):
         result = self.run_command(['file', 'volume-refresh', '102', '103'])
 
@@ -798,3 +816,7 @@ class FileTests(testing.TestCase):
             result = self.run_command(['file', 'snapshot-get-notification-status', '999'])
             self.assert_no_fail(result)
             self.assertIn(expect, result.output)
+
+    def test_volume_options(self):
+        result = self.run_command(['file', 'volume-options'])
+        self.assert_no_fail(result)
