@@ -41,17 +41,24 @@ class ServerCLITests(testing.TestCase):
                 {
                     "password": "abc123",
                     "username": "root"
-                }
-            ]}]
+                }],
+                'softwareLicense': {
+                    'softwareDescription':
+                        {
+                            'referenceCode': 'CENTOS_7_64',
+                            'version': '7.8 - 64',
+                            'name': 'Centos'
+                        }}}]
         }
         result = self.run_command(['hardware', 'credentials', '12345'])
 
         self.assert_no_fail(result)
-        self.assertEqual(json.loads(result.output),
-                         [{
-                             'username': 'root',
-                             'password': 'abc123'
-                         }])
+        self.assertEqual(json.loads(result.output), [
+            {'Password': 'abc123',
+             'Software': 'Centos',
+             'Username': 'root',
+             'Version': '7.8 - 64'}
+        ])
 
     def test_server_credentials_exception_passwords_not_found(self):
         mock = self.set_mock('SoftLayer_Hardware_Server', 'getObject')
@@ -85,7 +92,13 @@ class ServerCLITests(testing.TestCase):
                 {
                     "hardwareId": 22222,
                     "id": 333333,
-                    "passwords": [{}]
+                    "passwords": [{}],
+                    "softwareLicense": {
+                        "softwareDescription": {
+                            "name": None,
+                            "version": None
+                        }
+                    }
                 }
             ]
         }
@@ -704,19 +717,19 @@ class ServerCLITests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-            'type': 'a',
-            'host': 'hardware-test1',
-            'domainId': 12345,  # from SoftLayer_Account::getDomains
-            'data': '172.16.1.100',
-            'ttl': 7200
-        },)
+                           'type': 'a',
+                           'host': 'hardware-test1',
+                           'domainId': 12345,  # from SoftLayer_Account::getDomains
+                           'data': '172.16.1.100',
+                           'ttl': 7200
+                       },)
         createPTRargs = ({
-            'type': 'ptr',
-            'host': '100',
-            'domainId': 123456,
-            'data': 'hardware-test1.test.sftlyr.ws',
-            'ttl': 7200
-        },)
+                             'type': 'ptr',
+                             'host': '100',
+                             'domainId': 123456,
+                             'data': 'hardware-test1.test.sftlyr.ws',
+                             'ttl': 7200
+                         },)
 
         result = self.run_command(['hw', 'dns-sync', '1000'])
 
@@ -759,12 +772,12 @@ class ServerCLITests(testing.TestCase):
             }
         }
         createV6args = ({
-            'type': 'aaaa',
-            'host': 'hardware-test1',
-            'domainId': 12345,  # from SoftLayer_Account::getDomains
-            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-            'ttl': 7200
-        },)
+                            'type': 'aaaa',
+                            'host': 'hardware-test1',
+                            'domainId': 12345,  # from SoftLayer_Account::getDomains
+                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+                            'ttl': 7200
+                        },)
         server.return_value = test_server
         result = self.run_command(['hw', 'dns-sync', '--aaaa-record', '1000'])
         self.assert_no_fail(result)
@@ -1026,3 +1039,32 @@ class ServerCLITests(testing.TestCase):
                                    '--flavor', 'B1_2X8X25', '--datacenter', 'mex01', '--os', 'UBUNTU_LATEST'])
         self.assert_no_fail(result)
         self.assertNotIn('Warning: Closed soon: mex01', result.output)
+
+    def test_notifications(self):
+        result = self.run_command(['hardware', 'notifications', '100'])
+        self.assert_no_fail(result)
+
+    def test_add_notification(self):
+        result = self.run_command(['hardware', 'notification-add', '100', '--users', '123456'])
+        self.assert_no_fail(result)
+
+    def test_notification_delete(self):
+        result = self.run_command(['hardware', 'notification-delete', '100'])
+        self.assert_no_fail(result)
+
+    def test_create_credential(self):
+        result = self.run_command(['hw', 'create-credential', '123456',
+                                   '--username', 'testslcli', '--password', 'test-123456',
+                                   '--notes', 'test slcli', '--system', 'system'])
+        self.assert_no_fail(result)
+
+    def test_list_hw_search_noargs(self):
+        result = self.run_command(['hw', 'list', '--search'])
+        self.assert_no_fail(result)
+        self.assert_called_with('SoftLayer_Search', 'advancedSearch', args=('_objectType:SoftLayer_Hardware ',))
+
+    def test_list_hw_search_noargs_domain(self):
+        result = self.run_command(['hw', 'list', '--search', '-Dtest'])
+        self.assert_no_fail(result)
+        self.assert_called_with('SoftLayer_Search', 'advancedSearch',
+                                args=('_objectType:SoftLayer_Hardware  domain: *test*',))
